@@ -68,7 +68,6 @@ Block.getCadToolBarPanel = function() {
         action.setScriptFile(Block.includeBasePath + "/Block.js");
         action.objectName = actionName;
         action.setRequiresDocument(true);
-        action.setIcon(Block.includeBasePath + "/Block.svg");
         //action.setStatusTip(qsTr("Show block tools"));
         action.setDefaultShortcut(new QKeySequence("w,b"));
         action.setNoState();
@@ -171,9 +170,9 @@ Block.editBlock = function(di, blockName) {
     var doc = di.getDocument();
     var views = EAction.getGraphicsViews(di);
 
-    var i, view, blockZoom;
+    var i, view;
 
-    if (doc.getWorkingSetBlockReferenceId()!==RObject.INVALID_ID) {
+    if (doc.isEditingWorkingSet()) {
         EAction.handleUserWarning(qsTr("Cannot edit block while editing a block in-place"));
         return;
     }
@@ -182,18 +181,14 @@ Block.editBlock = function(di, blockName) {
     var blockId = doc.getCurrentBlockId();
     for (i=0; i<views.length; i++) {
         view = views[i];
+        var viewWidget = view.getWidget();
 
-        if (!isFunction(view.property)) {
+        if (isNull(viewWidget) || !isFunction(viewWidget.property)) {
             continue;
         }
 
-        blockZoom = view.property("blockZoom");
-        if (isNull(blockZoom)) {
-            blockZoom = new Object();
-        }
-
-        blockZoom[blockId] = [view.getFactor(), view.getOffset()];
-        view.setProperty("blockZoom", blockZoom);
+        viewWidget.setProperty("BlockZoomFactor_" + blockId, view.getFactor());
+        viewWidget.setProperty("BlockZoomOffset_" + blockId, view.getOffset());
         //print("stored zoom for block: ", blockId, ", view: ", i, ", factor: ", view.getFactor());
     }
 
@@ -204,23 +199,21 @@ Block.editBlock = function(di, blockName) {
     blockId = doc.getCurrentBlockId();
     for (i=0; i<views.length; i++) {
         view = views[i];
+        var viewWidget = view.getWidget();
 
-        if (!isFunction(view.property)) {
+        if (isNull(viewWidget) || !isFunction(viewWidget.property)) {
             continue;
         }
 
-        blockZoom = view.property("blockZoom");
-        if (isNull(blockZoom)) {
-            view.autoZoom(-1, true);
-            continue;
-        }
+        var blockZoomFactor = viewWidget.property("BlockZoomFactor_" + blockId);
+        var blockZoomOffset = viewWidget.property("BlockZoomOffset_" + blockId);
 
-        if (isNull(blockZoom[blockId]) || blockZoom[blockId].length!==2) {
+        if (isNull(blockZoomFactor) || isNull(blockZoomOffset)) {
             view.autoZoom(-1, true);
         }
         else {
-            view.setFactor(blockZoom[blockId][0]);
-            view.setOffset(blockZoom[blockId][1]);
+            view.setFactor(blockZoomFactor);
+            view.setOffset(blockZoomOffset);
             //print("restored zoom for block: ", blockId, ", view: ", i, ", factor: ", view.getFactor());
         }
     }
