@@ -148,9 +148,12 @@ EAction.prototype.finishEvent = function() {
     // reset CAD tool bar:
     if (!isNull(guiAction) && guiAction.getGroup() === "") {
         var appWin = EAction.getMainWindow();
-        var cadToolBar = appWin.findChild("CadToolBar");
-        if (!isNull(cadToolBar) && cadToolBar.getCurrentPanelName()==="SnapToolsPanel") {
-            cadToolBar.back();
+        if (!isNull(appWin)) {
+            // appWin can be NULL if it is being deleted
+            var cadToolBar = appWin.findChild("CadToolBar");
+            if (!isNull(cadToolBar) && cadToolBar.getCurrentPanelName()==="SnapToolsPanel") {
+                cadToolBar.back();
+            }
         }
     }
 
@@ -762,7 +765,7 @@ EAction.prototype.setCrosshairCursor = function() {
             EAction.crossCursor = new QCursor(Qt.CrossCursor);
         }
         else {
-            var bitmap, mask
+            var bitmap, mask;
             if (RSettings.getDevicePixelRatio()===2 && RS.getSystemId()!=="osx") {
                 bitmap = new QBitmap(EAction.includeBasePath + "/CrosshairCursor@2x.png", "PNG");
                 mask = new QBitmap(EAction.includeBasePath + "/CrosshairCursorMask@2x.png", "PNG");
@@ -794,6 +797,16 @@ EAction.prototype.setCursor = function(cursor, name) {
     if (!isNull(di)) {
         di.setCursor(cursor);
     }
+    var appWin = EAction.getMainWindow();
+    if (!isNull(appWin)) {
+        if (isNull(name)) {
+            appWin.setProperty("MouseCursor", "");
+        }
+        else {
+            appWin.setProperty("MouseCursor", name);
+        }
+    }
+
 //    if (!isNull(name)) {
 //        var views = this.getGraphicsViews();
 //        for (var i=0; i<views.length; i++) {
@@ -964,6 +977,15 @@ EAction.getGraphicsView = function() {
     return di.getLastKnownViewWithFocus();
 };
 
+EAction.getGraphicsViewWidget = function() {
+    var view = EAction.getGraphicsView();
+    if (isNull(view)) {
+        return undefined;
+    }
+
+    return view.getWidget();
+};
+
 /**
  * \return the existing menu with the given object name or, if no such menu
  * exists, a new menu with the given title and the given object name.
@@ -992,7 +1014,8 @@ EAction.getMenu = function(title, objectName, initFunction) {
     if (isNull(menu)) {
         menu = new QMenu(title, menuBar);
         menu.objectName = objectName;
-        menuBar.addMenu(menu);
+        var action = menuBar.addMenu(menu);
+        action.objectName = objectName + "Action";
         if (initFunction != undefined) {
             initFunction(menu);
         }
@@ -2145,7 +2168,7 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
     // multiple entities under cursor, offer context menu:
     var ret = RObject.INVALID_ID;
     var doc = di.getDocument();
-    var menu = new QMenu(EAction.getGraphicsView());
+    var menu = new QMenu(EAction.getGraphicsViewWidget());
     menu.objectName = "EntityContextMenu";
 
     // reacts to hovering and clicking of context menu items:
