@@ -48,6 +48,7 @@ Print.defaultPrinter = undefined;
 
 Print.getDefaultPrinter = function() {
     if (isNull(Print.defaultPrinter)) {
+        // TODO: this can be extremely slow if the default printer is a network printer:
         Print.defaultPrinter = new QPrinter();
     }
     return Print.defaultPrinter;
@@ -115,20 +116,19 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         }
     }
 
-    // QPrinter.Custom is deprecated / undefined:
-//    var paperSizeEnum = Print.getPaperSizeEnum(this.document);
-//    if (paperSizeEnum!==QPrinter.Custom) {
-//        printer.setPaperSize(paperSizeEnum);
-//    }
-//    else {
-        //printer.setPaperSize(QPrinter.Custom);
-
-        // always use custom page size to work around Qt page size limitations:
-        var paperSizeMM = Print.getPaperSizeMM(this.document);
+    // always use custom page size to work around Qt page size limitations:
+    var paperSizeMM = Print.getPaperSizeMM(this.document);
+    if (RSettings.getQtVersion() >= 0x060000) {
+        printer.setPageSize(new QPageSize(paperSizeMM, QPageSize.Millimeter));
+        printer.setFullPage(true);
+        printer.setPageOrientation(Print.getPageOrientationEnum(this.document));
+    }
+    else {
         printer.setPaperSize(paperSizeMM, QPrinter.Millimeter);
-//    }
-    printer.setFullPage(true);
-    printer.setOrientation(Print.getPageOrientationEnum(this.document));
+        printer.setFullPage(true);
+        printer.setOrientation(Print.getPageOrientationEnum(this.document));
+    }
+
 
     var colorMode = Print.getColorMode(this.document);
     if (colorMode == RGraphicsView.FullColor) {
@@ -147,7 +147,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         if (RSettings.isQt(5)) {
             Print.printDialog.rejected.connect(function() { Print.cancel = true; });
             Print.printDialog.exec();
-            Print.printDialog.destroy();
+            destr(Print.printDialog);
             EAction.activateMainWindow();
         }
         else {
@@ -158,7 +158,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
                             Print.cancel = false;
                             Print.printDialog.close();
                             if (RS.getSystemId()==="osx") {
-                                Print.printDialog.destroy();
+                                destr(Print.printDialog);
                                 EAction.activateMainWindow();
                             }
                         });
@@ -168,7 +168,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
                             Print.cancel = true;
                             Print.printDialog.close();
                             if (RS.getSystemId()==="osx") {
-                                Print.printDialog.destroy();
+                                destr(Print.printDialog);
                                 EAction.activateMainWindow();
                             }
                         });
@@ -186,7 +186,7 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         }
 
         if (Print.cancel===true) {
-            printer.destroy();
+            destr(printer);
             return undefined;
         }
     }
@@ -216,7 +216,7 @@ Print.prototype.print = function(pdfFile, printerName, pdfVersion) {
 
     var painter = new QPainter();
     if (!painter.begin(printer)) {
-        printer.destroy();
+        destr(printer);
         return false;
     }
 
@@ -228,7 +228,7 @@ Print.prototype.print = function(pdfFile, printerName, pdfVersion) {
     //}
 
     painter.end();
-    printer.destroy();
+    destr(printer);
 
     return true;
 };
@@ -270,9 +270,17 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     var heightInMM = printer.paperRect(QPrinter.Millimeter).height();
 
     // factor from mm to printer unit:
+    var paperRect;
+    if (RSettings.getQtVersion() >= 0x060000) {
+        paperRect = printer.pageLayout().fullRectPixels(printer.resolution());
+    }
+    else {
+        paperRect = printer.paperRect();
+    }
+
     var printerFactor = new RVector(
-        printer.paperRect().width() / widthInMM,
-        printer.paperRect().height() / heightInMM
+        paperRect.width() / widthInMM,
+        paperRect.height() / heightInMM
     );
 
     // printer calibration:
@@ -294,8 +302,8 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     var previousPixelSizeHint = this.scene.getPixelSizeHint();
 
     var widthInDrawingUnits = RUnit.convert(widthInMM, RS.Millimeter, this.document.getUnit());
-    if (printer.paperRect().width()>0) {
-        var pixelSizeHint = 1.0/printer.paperRect().width()*widthInDrawingUnits;
+    if (paperRect.width()>0) {
+        var pixelSizeHint = 1.0/paperRect.width()*widthInDrawingUnits;
         pixelSizeHint = pixelSizeHint / scale;
         this.scene.setPixelSizeHint(pixelSizeHint);
     }
@@ -334,7 +342,7 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
         if (!qclr.equals(new QColor(Qt.white))) {
             painter.setWorldTransform(new QTransform());
             painter.setBackground(new QBrush(qclr, Qt.SolidPattern));
-            painter.eraseRect(printer.paperRect());
+            painter.eraseRect(paperRect);
         }
 
         // paper size in mm:
@@ -426,7 +434,7 @@ Print.prototype.printPage = function(painter, rect) {
         )
     );
 
-    this.view.paintOverlay(painter);
+    this.view.paintOverlay();
 };
 
 /**
@@ -468,10 +476,10 @@ Print.autoFitDrawing = function(di, ori) {
     //qDebug("bb: ", bBox);
     if (ori) {
         if (bBox.getWidth()>bBox.getHeight()) {
-            Print.setPageOrientationEnum(di, QPrinter.Landscape);
+            Print.setPageOrientationEnum(di, RS.Landscape);
         }
         else {
-            Print.setPageOrientationEnum(di, QPrinter.Portrait);
+            Print.setPageOrientationEnum(di, RS.Portrait);
         }
     }
     Print.autoFitBox(di, bBox);
@@ -567,7 +575,14 @@ Print.centerBox = function(di, bBox) {
  * \param painter QPainter object if we are printing, RPainterPath for print preview.
  */
 Print.drawCropMarks = function(document, painter, border, printing) {
-    var isPainter = isFunction(painter.drawLinesF);
+    var isPainter;
+
+    if (RSettings.getQtVersion()>=0x060000) {
+        isPainter = isFunction(painter.drawLines);
+    }
+    else {
+        isPainter = isFunction(painter.drawLinesF);
+    }
 
     var clipping = false;
     if (isPainter) {
@@ -606,10 +621,15 @@ Print.drawCropMarks = function(document, painter, border, printing) {
         for (var k=0; k<lines.length; ++k) {
             lines[k].translate(-offset.x, -offset.y);
         }
-        painter.drawLinesF(lines);
+        if (RSettings.getQtVersion()>=0x060000) {
+            painter.drawLines(lines);
+        }
+        else {
+            painter.drawLinesF(lines);
+        }
     }
 
-    // preview:
+    // preview (painter path):
     else {
         for (var i=0; i<lines.length; ++i) {
             painter.moveTo(new RVector(lines[i].x1(), lines[i].y1()));
@@ -827,7 +847,7 @@ Print.getPages = function(document) {
     var w;
     var h;
     var paperSizeMM = Print.getPaperSizeMM(document);
-    if (Print.getPageOrientationEnum(document) === QPrinter.Portrait) {
+    if (Print.getPageOrientationEnum(document) === RS.Portrait) {
         w = paperSizeMM.width();
         h = paperSizeMM.height();
     } else {
@@ -1163,11 +1183,53 @@ Print.getPaperSizeMM = function(document) {
  * or QPrinter.
  */
 Print.getDefaultPaperSizeMM = function() {
-    var defaultPaperSizeMM = Print.getDefaultPrinter().paperSize(QPrinter.Millimeter);
+    var defaultPrinter = Print.getDefaultPrinter();
 
-    var dwMM = defaultPaperSizeMM.width();
-    var dhMM = defaultPaperSizeMM.height();
+    var dwMM;
+    var dhMM;
 
+    if (RSettings.getQtVersion() >= 0x060000) {
+        var defaultPaperSize = defaultPrinter.pageLayout().pageSize();
+
+        // paper size in appropriate unit:
+        var size = defaultPaperSize.definitionSize();
+        var wUnit = size.width();
+        var hUnit = size.height();
+
+        // unit of paper size:
+        var unit = defaultPaperSize.definitionUnits();
+
+        // convert unit to mm:
+        var factor = 1.0;
+        switch (unit) {
+        case QPageSize.Point:
+            factor = 72 / 25.4;
+            break;
+        case QPageSize.Inch:
+            factor = 25.4;
+            break;
+        case QPageSize.Pica:
+            factor = 6 / 25.4;
+            break;
+        case QPageSize.Didot:
+            factor = 1 / 0.365;
+            break;
+        case QPageSize.Cicero:
+            factor = 1 / 4.5;
+            break;
+        default:
+        case QPageSize.Millimeter:
+            factor = 1.0;
+            break;
+        }
+        dwMM = wUnit * factor;
+        dhMM = hUnit * factor;
+    }
+    else {
+        var defaultPaperSizeMM = defaultPrinter.paperSize(QPrinter.Millimeter);
+        dwMM = defaultPaperSizeMM.width();
+        dhMM = defaultPaperSizeMM.height();
+    }
     // get w / h in paper unit from settings:
     var dw = RUnit.convert(dwMM, RS.Millimeter, Print.getDefaultPaperUnit());
     var dh = RUnit.convert(dhMM, RS.Millimeter, Print.getDefaultPaperUnit());
@@ -1366,10 +1428,10 @@ Print.getDefaultPaperSizeName = function(document) {
 Print.getPageOrientationEnum = function(document) {
     var pageOrientationString = Print.getPageOrientationString(document);
     if (pageOrientationString==="Landscape") {
-        return QPrinter.Landscape;
+        return RS.Landscape;
     }
     else {
-        return QPrinter.Portrait;
+        return RS.Portrait;
     }
 };
 
@@ -1382,7 +1444,7 @@ Print.setPageOrientationString = function(di, pageOrientation) {
 };
 
 Print.setPageOrientationEnum = function(di, pageOrientation) {
-    if (pageOrientation.valueOf()===QPrinter.Landscape.valueOf()) {
+    if (pageOrientation===RS.Landscape) {
         Print.setPageOrientationString(di, "Landscape");
     }
     else {
