@@ -60,6 +60,11 @@ PrintPreview.isRunning = function() {
  * Starts the print preview.
  */
 PrintPreview.start = function(initialAction, instance) {
+    var appWin = RMainWindowQt.getMainWindow();
+
+    // disable app window as this might be very slow on a system with a network printer as default printer:
+    appWin.enabled = false;
+
     var di = EAction.getDocumentInterface();
     var doc = di.getDocument();
 
@@ -76,8 +81,7 @@ PrintPreview.start = function(initialAction, instance) {
     }
 
     // auto setup:
-    var appWin = RMainWindowQt.getMainWindow();
-    var buttons = new QMessageBox.StandardButtons(QMessageBox.Yes, QMessageBox.No);
+    var buttons = makeQMessageBoxStandardButtons(QMessageBox.Yes, QMessageBox.No);
 
     var paperSizeMM = Print.getPaperSizeMM(doc);
     var paperSizeName = Print.getPaperSizeNameFromSize(paperSizeMM);
@@ -144,12 +148,17 @@ PrintPreview.start = function(initialAction, instance) {
         ga.setChecked(true);
     }
 
+    appWin.enabled = true;
+
 };
 
 /**
  * Exits the print preview.
  */
 PrintPreview.exit = function() {
+    //var appWin = RMainWindowQt.getMainWindow();
+    //appWin.enabled = false;
+
     var di = EAction.getDocumentInterface();
     var a = di.getDefaultAction();
     a.finishEvent();
@@ -159,6 +168,8 @@ PrintPreview.exit = function() {
     if (!isNull(ga)) {
         ga.setChecked(false);
     }
+
+    //appWin.enabled = true;
 };
 
 PrintPreview.prototype.beginEvent = function() {
@@ -223,7 +234,6 @@ PrintPreviewImpl.State = {
 };
 
 PrintPreviewImpl.prototype.beginEvent = function() {
-    qDebug("PrintPreviewImpl.prototype.beginEvent");
     var di = this.getDocumentInterface();
 
     var appWin = RMainWindowQt.getMainWindow();
@@ -272,16 +282,20 @@ PrintPreviewImpl.prototype.beginEvent = function() {
     }
 
     var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
-    action.triggered.connect(this, "updateBackgroundDecoration");
+    action.triggered.connect(this, this.updateBackgroundDecoration);
 
     if (initialZoom==="Auto") {
         // auto fit drawing and auto set orientation:
         this.slotAutoFitDrawing(true);
+
+        appWin.setProperty("PrintPreview/InitialZoom", "Stored");
     }
     else if (initialZoom==="View") {
         Print.setColumns(di, 1);
         Print.setRows(di, 1);
         this.slotAutoFitBox(this.view.getBox());
+
+        appWin.setProperty("PrintPreview/InitialZoom", "Stored");
     }
 
     if (this.initialAction==="Print") {
@@ -294,14 +308,14 @@ PrintPreviewImpl.prototype.beginEvent = function() {
     // create listener to update preview when preferences changed:
     this.pAdapter = new RPreferencesListenerAdapter();
     appWin.addPreferencesListener(this.pAdapter);
-    this.pAdapter.preferencesUpdated.connect(this, "updateFromPreferences");
+    this.pAdapter.preferencesUpdated.connect(this, this.updateFromPreferences);
 
     this.bAdapter = new RBlockListenerAdapter();
     appWin.addBlockListener(this.bAdapter);
-    this.bAdapter.blocksUpdated.connect(this, "updateBackgroundTransform");
-    this.bAdapter.currentBlockSet.connect(this, "updateBackgroundTransform");
-    this.bAdapter.blocksUpdated.connect(this, "updateBackgroundDecoration");
-    this.bAdapter.currentBlockSet.connect(this, "updateBackgroundDecoration");
+    this.bAdapter.blocksUpdated.connect(this, this.updateBackgroundTransform);
+    this.bAdapter.currentBlockSet.connect(this, this.updateBackgroundTransform);
+    this.bAdapter.blocksUpdated.connect(this, this.updateBackgroundDecoration);
+    this.bAdapter.currentBlockSet.connect(this, this.updateBackgroundDecoration);
 };
 
 /**
@@ -356,7 +370,7 @@ PrintPreviewImpl.prototype.finishEvent = function() {
         }
 
         var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
-        action.triggered.disconnect(this, "updateBackgroundDecoration");
+        action.triggered.disconnect(this, this.updateBackgroundDecoration);
     }
 
     //PrintPreviewImpl.setRunning(false);
@@ -379,9 +393,11 @@ PrintPreviewImpl.prototype.finishEvent = function() {
 
     if (!isNull(this.pAdapter)) {
         appWin.removePreferencesListener(this.pAdapter);
+        destr(this.pAdapter);
     }
     if (!isNull(this.bAdapter)) {
         appWin.removeBlockListener(this.bAdapter);
+        destr(this.bAdapter);
     }
 };
 
@@ -526,7 +542,7 @@ PrintPreviewImpl.prototype.showUiOptions = function(resume) {
 
     widgets["Portrait"].blockSignals(true);
     widgets["Landscape"].blockSignals(true);
-    if (Print.getPageOrientationEnum(document).valueOf() === QPrinter.Portrait.valueOf()) {
+    if (Print.getPageOrientationEnum(document) === RS.Portrait) {
         widgets["Portrait"].checked=true;
     } else {
         widgets["Landscape"].checked=true;
@@ -656,8 +672,7 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
     path = new RPainterPath();
     path.setPen(new QPen(new QColor(0x84, 0x84, 0xff)));
     if (!Print.getShowPaperBorders(document)) {
-        color = new QColor(backgroundColor.red(), backgroundColor.green(),
-                backgroundColor.blue());
+        color = new QColor(backgroundColor.red(), backgroundColor.green(), backgroundColor.blue());
         path.setBrush(new QBrush(color));
     } else {
         path.setBrush(new QBrush(Qt.NoBrush));
@@ -1009,7 +1024,7 @@ PrintPreviewImpl.prototype.slotPortraitChanged = function() {
         return;
     }
     var di = this.getDocumentInterface();
-    Print.setPageOrientationEnum(di, QPrinter.Portrait);
+    Print.setPageOrientationEnum(di, RS.Portrait);
 
     this.updateBackgroundDecoration();
     this.slotAutoZoomToPage();
@@ -1020,7 +1035,7 @@ PrintPreviewImpl.prototype.slotLandscapeChanged = function() {
         return;
     }
     var di = this.getDocumentInterface();
-    Print.setPageOrientationEnum(di, QPrinter.Landscape);
+    Print.setPageOrientationEnum(di, RS.Landscape);
 
     this.updateBackgroundDecoration();
     this.slotAutoZoomToPage();
