@@ -41,7 +41,7 @@ Explode.initPreferences = function(pageWidget, calledByPrefDialog, document) {
         widgets["SplineTolerance"].visible = false;
         widgets["SplineTolerance_Label"].visible = false;
         widgets["SplinesToLineSegments"].visible = false;
-        widgets["Indent"].destroy();
+        destr(widgets["Indent"]);
         pageWidget.findChild("GridLayout").addWidget(widgets["SplineSegments_Label"], 2, 0, 1, 2);
     }
     else {
@@ -152,10 +152,12 @@ Explode.explodeSelection = function(di, toolTitle) {
             op.deleteObject(entity);
         }
     }
-    di.applyOperation(op);
+
+    var t = di.applyOperation(op);
 
     // update block reference attributes:
     if (attributeEntities.length>0) {
+
         op = new RAddObjectsOperation();
         //op.setTransactionGroup(doc.getTransactionGroup());
         if (!isNull(toolTitle)) {
@@ -166,11 +168,22 @@ Explode.explodeSelection = function(di, toolTitle) {
         for (i=0; i<attributeEntities.length; i++) {
             var attributeEntity = attributeEntities[i].clone();
 
+            if (RSettings.getQtVersion()>=0x060000) {
+                var newAttributeId = t.getNewObjectId(attributeEntity.getId());
+                storage.setObjectId(attributeEntity, newAttributeId);
+            }
+
             // find parent entity of attribute:
             var blockReferenceEntity = blockReferenceMap[attributeEntity.getParentId()];
             if (!isNull(blockReferenceEntity)) {
                 // update parent ID:
-                storage.setEntityParentId(attributeEntity, blockReferenceEntity.getId());
+                if (RSettings.getQtVersion()>=0x060000) {
+                    var newAttributeParentId = t.getNewObjectId(blockReferenceEntity.getId());
+                    storage.setEntityParentId(attributeEntity, newAttributeParentId);
+                }
+                else {
+                    storage.setEntityParentId(attributeEntity, blockReferenceEntity.getId());
+                }
                 op.addObject(attributeEntity, false);
             }
         }
@@ -649,9 +662,60 @@ Explode.explodeEntity = function(entity, options) {
                     continue;
                 }
 
-                // ignore hatch in non-uniformly scaled block reference:
+                // hatch in non-uniformly scaled block reference:
                 if (!uniform && isHatchEntity(subEntity)) {
-                    EAction.handleUserWarning(qsTr("Ignored hatch in block reference with non-uniform scale factors"));
+                    // query source entity from block (no transform):
+                    var untransformedSubEntity = data.queryEntity(subIds[k], false);
+
+                    // explode source entity:
+                    var untransformedEntitites = Explode.explodeEntity(untransformedSubEntity, options);
+
+                    var explodedHatchData = undefined;
+                    if (subEntity.isSolid()) {
+                        // solid hatch: create new solid hatch:
+                        explodedHatchData = new RHatchData();
+                        explodedHatchData.newLoop();
+                    }
+
+                    // transform by block transforms:
+                    for (var n=0; n<untransformedEntitites.length; n++) {
+                        var untransformedEntity = untransformedEntitites[n];
+
+                        if (isShape(untransformedEntity)) {
+                            untransformedEntity = shapeToEntity(document, untransformedEntity);
+                        }
+
+                        e = data.getTransformed(untransformedEntity);
+
+                        if (!isNull(explodedHatchData)) {
+                            // solid hatch: add transformed boundary to exploded hatch entity:
+                            explodedHatchData.addBoundary(e.castToShape());
+                        }
+                        else {
+                            // hatch pattern: add transformed entity:
+                            e.setSelected(true);
+                            if (isFunction(subEntity.data)) {
+                                e.copyAttributesFrom(getPtr(subEntity));
+                            }
+                            else {
+                                e.copyAttributesFrom(subEntity);
+                            }
+                            ret.push(e);
+                        }
+                    }
+
+                    if (!isNull(explodedHatchData)) {
+                        // solid hatch: add new solid hatch:
+                        e = new RHatchEntity(document, explodedHatchData);
+                        e.setSelected(true);
+                        if (isFunction(subEntity.data)) {
+                            e.copyAttributesFrom(getPtr(subEntity));
+                        }
+                        else {
+                            e.copyAttributesFrom(subEntity);
+                        }
+                        ret.push(e);
+                    }
                     continue;
                 }
 
