@@ -59,8 +59,9 @@ function RBlockListQt(parent, addListener, showHeader) {
         this.header().setResizeMode(BlockList.colEdit, QHeaderView.Interactive);
     }
 
-    this.setColumnWidth(BlockList.colVisible, 22);
-    this.setColumnWidth(BlockList.colEdit, 22);
+    // Qt 6.6.1 workaround: this only works once widget is visible:
+    // for tests, we also need it here:
+    BlockList.initColumnWidths(this);
 
     var self = this;
     if (addListener) {
@@ -514,6 +515,16 @@ BlockList.getActiveItem = function() {
     return blockList.getActiveItem();
 };
 
+BlockList.getSelectedItems = function() {
+    var appWin = RMainWindowQt.getMainWindow();
+    var blockList = appWin.findChild("BlockList");
+    if (isNull(blockList)) {
+        return undefined;
+    }
+
+    return blockList.selectedItems();
+};
+
 /**
  * Shows / hides the block list.
  */
@@ -536,6 +547,10 @@ BlockList.prototype.finishEvent = function() {
     this.getGuiAction().setChecked(dock.visible);
 };
 
+BlockList.initColumnWidths = function(blockList) {
+    blockList.setColumnWidth(BlockList.colVisible, 22);
+    blockList.setColumnWidth(BlockList.colEdit, 22);
+};
 
 /**
  * Initializes the block list widget.
@@ -546,7 +561,6 @@ BlockList.init = function(basePath) {
     var action = new RGuiAction(qsTr("Block List"), appWin);
     action.setRequiresDocument(false);
     action.setScriptFile(basePath + "/BlockList.js");
-    action.setIcon(basePath + "/BlockList.svg");
     action.setDefaultShortcut(new QKeySequence("g,b"));
     action.setDefaultCommands(["gb"]);
     action.setGroupSortOrder(3600);
@@ -593,7 +607,13 @@ BlockList.init = function(basePath) {
     dock.setWidget(formWidget);
     appWin.addDockWidget(Qt.RightDockWidgetArea, dock);
 
-    dock.shown.connect(function() { action.setChecked(true); });
+
+    dock.shown.connect(function() {
+        action.setChecked(true);
+
+        // Qt 6.6.1 workaround: this only works once widget is visible:
+        BlockList.initColumnWidths(blockList);
+    });
     dock.hidden.connect(function() { action.setChecked(false); });
 
     dock.visible = false;
