@@ -77,7 +77,6 @@ CommandLine.init = function(basePath) {
     var action = new RGuiAction(qsTr("&Command Line"), appWin);
     action.setRequiresDocument(false);
     action.setScriptFile(basePath + "/CommandLine.js");
-    action.setIcon(basePath + "/CommandLine.svg");
     action.setDefaultShortcut(new QKeySequence("g,m"));
     action.setDefaultCommands(["gm"]);
     action.setGroupSortOrder(3800);
@@ -223,7 +222,7 @@ CommandLine.init = function(basePath) {
         di.setCursorPosition(pos);
         appWin.notifyCoordinateListeners(di);
 
-        e = new RCoordinateEvent(pos, view.getScene(), view.getRGraphicsView());
+        e = new RCoordinateEvent(pos, view.getScene(), getRGraphicsView(view));
         di.clearPreview();
         di.coordinateEventPreview(e);
         di.repaintViews();
@@ -305,7 +304,7 @@ CommandLine.init = function(basePath) {
                 }
 
                 var view = di.getLastKnownViewWithFocus();
-                e = new RCoordinateEvent(pos, view.getScene(), view.getRGraphicsView());
+                e = new RCoordinateEvent(pos, view.getScene(), getRGraphicsView(view));
                 di.coordinateEvent(e);
                 appWin.handleUserCommand(command);
                 leCommand.clear();
