@@ -40,9 +40,6 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
     // only do something if the value has actually changed
     // remember edited status of widgets
 
-//    qDebug("propertyChanged:", value);
-//    qDebug("propertyChanged: sender: ", this.sender);
-
     var attributes = this.propertyEditor.getPropertyAttributes(this.propertyType);
 
     var typeHint = RS.UnknownType;
@@ -61,6 +58,16 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
         return;
     }
 
+    // value is QFont:
+    else if (isOfType(this.sender, QFontComboBox)) {
+        var fontFamily = value.family();
+        if (fontFamily.length===0) {
+            // font varies:
+            return;
+        }
+        value = fontFamily;
+    }
+
     // value comes from a combo box:
     else if (isComboBox(this.sender)) {
         // value is index of combo box:
@@ -433,6 +440,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         gridLayoutGeometry = new QGridLayout(this.geometryGroup);
         gridLayoutGeometry.setVerticalSpacing(2);
         gridLayoutGeometry.setHorizontalSpacing(2);
+        gridLayoutGeometry.setContentsMargins(6,6,6,6);
         // label:
         gridLayoutGeometry.setColumnStretch(0,0);
         // control:
@@ -507,12 +515,6 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                     continue;
                 }
 
-                // qt 6: detect wrapper of QGroupBox and never delete that:
-                if (!isNull(child.wrappedType)) {
-                    continue;
-                }
-
-
                 destr(child);
             }
         }
@@ -1319,6 +1321,9 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
             control.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
             control.focusPolicy = Qt.ClickFocus;
             initFontComboBox(control);
+            control.objectName = objectName;
+            var pw = new PropertyWatcher(this, control, propertyTypeId);
+            control.currentFontChanged.connect(pw, pw.propertyChanged);
         }
         else {
             control = new QComboBox(this.geometryGroup);
@@ -1326,28 +1331,29 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
             control.focusPolicy = Qt.ClickFocus;
             control.minimumWidth = 50;
             control.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Preferred);
-        }
 
-        control.objectName = objectName;
+            control.objectName = objectName;
 
-        if (isNull(choicesData)/* && propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
-            var pw = new PropertyWatcher(this, control, propertyTypeId)
-            if (RSettings.getQtVersion() >= 0x060000) {
-                control.textActivated.connect(pw, pw.propertyChanged);
+            if (isNull(choicesData)/* && propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
+                var pw = new PropertyWatcher(this, control, propertyTypeId);
+                if (RSettings.getQtVersion() >= 0x060000) {
+                    control.textActivated.connect(pw, pw.propertyChanged);
+                }
+                else {
+                    control['activated(QString)'].connect(pw, pw.propertyChanged);
+                }
             }
             else {
-                control['activated(QString)'].connect(pw, pw.propertyChanged);
-            }
-        }
-        else {
-            var pw = new PropertyWatcher(this, control, propertyTypeId);
-            if (RSettings.getQtVersion() >= 0x060000) {
-                control.activated.connect(pw, pw.propertyChanged);
-            }
-            else {
-                control['activated(int)'].connect(pw, pw.propertyChanged);
+                var pw = new PropertyWatcher(this, control, propertyTypeId);
+                if (RSettings.getQtVersion() >= 0x060000) {
+                    control.activated.connect(pw, pw.propertyChanged);
+                }
+                else {
+                    control['activated(int)'].connect(pw, pw.propertyChanged);
+                }
             }
         }
+
     }
 
     if (propertyTypeId.getId()===REntity.PropertyLayer.getId()) {
@@ -1483,7 +1489,9 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
         }
     }
     else {
+        var signalsBlocked = control.blockSignals(true);
         control.currentIndex = index;
+        control.blockSignals(signalsBlocked);
     }
 
     return [ control ];
@@ -1559,6 +1567,9 @@ PropertyEditorImpl.prototype.makeReadOnly = function(control) {
         return;
     }
 
+    RPropertyEditor.makeReadOnly(control, true);
+
+    /*
     var p = control.palette;
     if (isNull(control.property("oriPalette"))) {
         control.setProperty("oriPalette", control.palette);
@@ -1574,8 +1585,9 @@ PropertyEditorImpl.prototype.makeReadOnly = function(control) {
 //        p.setColor(QPalette.Base, new QColor("#eeeeee"));
 //    }
     control.palette = p;
+    */
 
-    control.readOnly = true;
+    //control.readOnly = true;
     // leave enabled to allow copy / page (20140411):
     //control.enabled = false;
 };
@@ -1588,22 +1600,25 @@ PropertyEditorImpl.prototype.makeReadWrite = function(control) {
         return;
     }
 
-    var p = control.palette;
-    if (isNull(control.property("oriPalette"))) {
-        control.setProperty("oriPalette", control.palette);
-    }
+    RPropertyEditor.makeReadOnly(control, false);
 
-    p.setColor(QPalette.Active, QPalette.Text, control.property("oriPalette").color(QPalette.Active, QPalette.WindowText));
-    p.setColor(QPalette.Inactive, QPalette.Text, control.property("oriPalette").color(QPalette.Inactive, QPalette.WindowText));
-//    //if (RSettings.hasDarkGuiBackground()) {
-//        p.setColor(QPalette.Base, control.oriBase);
-////    }
-////    else {
-////        p.setColor(QPalette.Base, new QColor("#ffffff"));
-////    }
-    control.palette = p;
+//    var p = control.palette;
+//    if (isNull(control.property("oriPalette"))) {
+//        control.setProperty("oriPalette", control.palette);
+//    }
+
+//    p.setColor(QPalette.Active, QPalette.Text, control.property("oriPalette").color(QPalette.Active, QPalette.WindowText));
+//    p.setColor(QPalette.Inactive, QPalette.Text, control.property("oriPalette").color(QPalette.Inactive, QPalette.WindowText));
+////    //if (RSettings.hasDarkGuiBackground()) {
+////        p.setColor(QPalette.Base, control.oriBase);
+//////    }
+//////    else {
+//////        p.setColor(QPalette.Base, new QColor("#ffffff"));
+//////    }
+//    control.palette = p;
+
+    //control.readOnly = false;
 
-    control.readOnly = false;
     control.enabled = true;
 };
 
@@ -1656,6 +1671,20 @@ PropertyEditor.getPreferencesCategory = function() {
     return [ qsTr("Widgets"), qsTr("Property Editor") ];
 };
 
+PropertyEditor.initPreferences = function(pageWidget, calledByPrefDialog, document) {
+    var w = pageWidget.findChild("Decimals");
+    w.addItem("0", 0);
+    w.addItem("1 (1/2)", 1);
+    w.addItem("2 (1/4)", 2);
+    w.addItem("3 (1/8)", 3);
+    w.addItem("4 (1/16)", 4);
+    w.addItem("5 (1/32)", 5);
+    w.addItem("6 (1/64)", 6);
+    w.addItem("7 (1/128)", 7);
+    w.addItem("8 (1/256)", 8);
+    w.currentIndex = 8;
+};
+
 PropertyEditor.applyPreferences = function(doc, mdiChild) {
     var appWin = RMainWindowQt.getMainWindow();
     appWin.notifyPropertyListeners(EAction.getDocument());
@@ -1669,7 +1698,7 @@ PropertyEditor.prototype.beginEvent = function() {
 
     var appWin = RMainWindowQt.getMainWindow();
     var dock = appWin.findChild("PropertyEditorDock");
-    if (!QCoreApplication.arguments().contains("-no-show")) {
+    if (!RSettings.getOriginalArguments().contains("-no-show")) {
         dock.visible = !dock.visible;
         if (dock.visible) dock.raise();
     }
@@ -1713,7 +1742,6 @@ PropertyEditor.init = function(basePath) {
     var action = new RGuiAction(qsTr("Property Editor"), appWin);
     action.setRequiresDocument(false);
     action.setScriptFile(basePath + "/PropertyEditor.js");
-    action.setIcon(basePath + "/PropertyEditor.svg");
     action.setDefaultShortcut(new QKeySequence("g,p"));
     action.setDefaultCommands(["gp"]);
     action.setGroupSortOrder(3700);
