@@ -161,7 +161,7 @@ function getPtr(p) {
 /**
  * Checks if the given object is undefined or null.
  *
- * \return true if the given object is defined and not null.
+ * \return false if the given object is defined and not null.
  * This method also supports shared pointers, i.e. obj.isNull()==true.
  */
 function isNull(obj) {
@@ -1286,9 +1286,9 @@ function entityTypeToString(type, plural) {
     case RS.EntityDimAngular:
         return plural ? qsTr("Angular Dimensions") : qsTr("Angular Dimension");
     case RS.EntityDimAngular2L:
-        return plural ? qsTr("Angular Dimensions (2 Line)") : qsTr("Angular Dimension (2 Line)");
+        return plural ? qsTr("Angular Dimensions (2 Lines)") : qsTr("Angular Dimension (2 Lines)");
     case RS.EntityDimAngular3P:
-        return plural ? qsTr("Angular Dimensions (3 Point)") : qsTr("Angular Dimension (3 Point)");
+        return plural ? qsTr("Angular Dimensions (3 Points)") : qsTr("Angular Dimension (3 Points)");
     case RS.EntityDimArcLength:
         return plural ? qsTr("Arc Dimension") : qsTr("Arc Dimension");
     case RS.EntityDimDiametric:
@@ -1491,7 +1491,19 @@ function objectFromPath(path) {
  */
 function getWidgetPath(widget) {
     var pw = widget.parentWidget();
-    var str = widget.objectName !== "" ? widget.objectName : widget.toString();
+    var str = "";
+    if (RSettings.getQtVersion()>=0x060000) {
+        if (widget.objectName !== "") {
+            str = widget.objectName;
+        }
+        else {
+            return getWidgetPath(pw);
+        }
+    }
+    else {
+        str = widget.objectName !== "" ? widget.objectName : widget.toString();
+    }
+
     if (isNull(pw)) {
         return str;
     }
@@ -2934,7 +2946,7 @@ function addActionsToWidgets() {
                         }
                         for (var si=0; si<shortcuts.length; si++) {
                             var scObj = new QShortcut(shortcuts[si], a.parentWidget(), 0, 0, Qt.WindowShortcut)
-                            scObj.activated.connect(a, "trigger");
+                            scObj.activated.connect(a, a.trigger);
                             scObjs.push(scObj);
                         }
                         appWin.setProperty("DelegatedShortcutsObjs", scObjs);
@@ -3321,6 +3333,12 @@ function makeQAbstractItemViewEditTriggers() {
     return makeFlags.apply(this, argumentsNew);
 }
 
+function makeQDirIteratorIteratorFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QDirIterator.IteratorFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
 function makeFlags() {
     if (RSettings.isQt(6)) {
         var ret = 0;
