@@ -494,18 +494,31 @@ function addObject(obj) {
         return obj.clone();
     }
     else {
+        var type = obj.getType();
         var di = getDocumentInterface();
-        di.applyOperation(new RAddObjectOperation(obj, false));
-        return obj.clone();
+        var doc = di.getDocument();
+        var storage = doc.getStorage();
+
+        var t = di.applyOperation(new RAddObjectOperation(obj, false));
+
+        // make sure returned object carries ID of added object:
+        var ret = obj.clone();
+        var ids = t.getAffectedObjects();
+        for (var i=0; i<ids.length; i++) {
+            var id = ids[i];
+            var e = doc.queryObject(id);
+            if (e.getType()===type) {
+                storage.setObjectId(ret, ids[i]);
+                break;
+            }
+        }
+        return ret;
     }
 }
 
 /**
  * Deletes the given RObject from the drawing.
  * \ingroup ecma_simple
- *
- * \return The added object. The object does not yet have a valid ID if it was added within a
- * transaction.
  */
 function deleteObject(obj) {
     if (isFunction(obj.data)) {
